{*******************************************************************************}
{                                                                               }
{ FileName  : UTabPageControlEditors.pas                                        }
{                                                                               }
{ Author    : Ian Lane (Email: lanei@ideal.net.au)                              }
{                                                                               }
{ Synopsis  : This unit contains all the component editors, property editors    }
{             and experts needed to integrate TTabPageControl into the Delphi   }
{             IDE. However, for clarity, each editor and expert is defined and  }
{             coded in its own file and then "included" here.                   }
{                                                                               }
{             Each editor/expert has two include files                          }
{                 --- a file named xxx1.pas which is the "header" or definition }
{                 --- a file named xxx2.pas which is the "implementation"       }
{                                                                               }
{ Warning   : This unit must NOT be included in a "uses" statement of any       }
{             applications you create. It accesses the Delphi IDE and will      }
{             cause your application to fail to compile.                        }
{                                                                               }
{ See also  : UTabPageControl.pas which contains the definition and             }
{             implementation of the TTabPageControl.                            }
{                                                                               }
{                          Copyright (c) 1997 Ian Lane                          }
{                                                                               }
{*******************************************************************************}

{DEFINE Debug}

{$IFDEF Debug}     // If we are debugging then check everything
{$O-,R+,S+,I+,Q+,D+,L+,Y+}
{$ELSE}            // If we are not debugging then minimise the compiled unit size
{$O+,R-,S-,I-,Q-,D-,Y-}
{$ENDIF}

{$BOOLEVAL OFF}

unit UTabPageControlEditors;

interface

uses
  Classes, DsgnIntf, UTabPageControl;

type
  // Forward define all our classes
  TActivePagePropertyEditor = class;
  TMethodPropertyEditor = class;
  TTabPageControlEditor = class;
  TTabPageSettingsEditor = class;

// Include the definitions of all the editors
{$INCLUDE IActivePagePropertyEditor1}
{$INCLUDE IMethodPropertyEditor1}
{$INCLUDE ITabPageControlEditor1}
{$INCLUDE ITabPageSettingsEditor1}

implementation

uses
  EditIntf, ExptIntf, fmRenameTabPage, fmScanningTTabPageControls, fmTabPageDescSettings,
  Forms, Graphics, IStreams, LibMain, Proxies, SysUtils, ToolIntf, TypInfo, Windows;

{$ifdef VER90}
// Define a function to enable us to access the Delphi IDE ToolServices component
function ToolServices : TIToolServices;

begin
  Result := AppBuilder.GetToolServices
end;
{$endif}

// Include all our "helper" units
{$INCLUDE IEnhIEditReader}

// Include the implementation of all the editors
{$INCLUDE IActivePagePropertyEditor2}
{$INCLUDE IMethodPropertyEditor2}
{$INCLUDE ITabPageControlEditor2}
{$INCLUDE ITabPageSettingsEditor2}

end.
